@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-history.c 7687 2007-11-13 23:15:57Z xan $
  */
 
 #include "config.h"
@@ -29,12 +28,11 @@
 #include "ephy-node-common.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
-#include "ephy-glib-compat.h"
+#include "ephy-string.h"
 
 #include <time.h>
 #include <string.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
 
 #define EPHY_HISTORY_XML_ROOT	 (const xmlChar *)"ephy_history"
 #define EPHY_HISTORY_XML_VERSION (const xmlChar *)"1.0"
@@ -88,42 +86,14 @@ enum
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL];
 
 static void ephy_history_class_init	(EphyHistoryClass *klass);
 static void ephy_history_init		(EphyHistory *history);
 static void ephy_history_finalize	(GObject *object);
 static gboolean impl_add_page           (EphyHistory *, const char *, gboolean, gboolean);
 
-static GObjectClass *parent_class = NULL;
-
-GType
-ephy_history_get_type (void)
-{
-        static GType type = 0;
-
-        if (G_UNLIKELY (type == 0))
-        {
-                const GTypeInfo our_info =
-                {
-                        sizeof (EphyHistoryClass),
-                        NULL, /* base_init */
-                        NULL, /* base_finalize */
-                        (GClassInitFunc) ephy_history_class_init,
-                        NULL,
-                        NULL, /* class_data */
-                        sizeof (EphyHistory),
-                        0, /* n_preallocs */
-                        (GInstanceInitFunc) ephy_history_init
-                };
-
-                type = g_type_register_static (G_TYPE_OBJECT,
-					       "EphyHistory",
-					       &our_info, 0);
-        }
-
-        return type;
-}
+G_DEFINE_TYPE (EphyHistory, ephy_history, G_TYPE_OBJECT)
 
 static void
 ephy_history_set_property (GObject *object,
@@ -162,8 +132,6 @@ ephy_history_class_init (EphyHistoryClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        parent_class = g_type_class_peek_parent (klass);
-
         object_class->finalize = ephy_history_finalize;
 	object_class->get_property = ephy_history_get_property;
 	object_class->set_property = ephy_history_set_property;
@@ -627,7 +595,7 @@ ephy_history_finalize (GObject *object)
 
 	LOG ("Global history finalized");
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (ephy_history_parent_class)->finalize (object);
 }
 
 EphyHistory *
@@ -658,11 +626,10 @@ ephy_history_host_visited (EphyHistory *eh,
 static EphyNode *
 internal_get_host (EphyHistory *eh, const char *url, gboolean create)
 {
-	GnomeVFSURI *vfs_uri = NULL;
 	EphyNode *host = NULL;
-	const char *host_name = NULL;
+	char *host_name = NULL;
 	GList *host_locations = NULL, *l;
-	const char *scheme = NULL;
+	char *scheme = NULL;
 	GTime now;
 
 	g_return_val_if_fail (url != NULL, NULL);
@@ -674,24 +641,22 @@ internal_get_host (EphyHistory *eh, const char *url, gboolean create)
 
 	now = time (NULL);
 
-	vfs_uri = gnome_vfs_uri_new (url);
-
-	if (vfs_uri)
+	if (url)
 	{
-		scheme = gnome_vfs_uri_get_scheme (vfs_uri);
-		host_name = gnome_vfs_uri_get_host_name (vfs_uri);
+		scheme = g_uri_parse_scheme (url);
+		host_name = ephy_string_get_host_name (url);
 	}
 
 	/* Build an host name */
 	if (scheme == NULL || host_name == NULL)
 	{
-		host_name = _("Others");
+		host_name = g_strdup (_("Others"));
 		host_locations = g_list_append (host_locations,
 						g_strdup ("about:blank"));
 	}
 	else if (strcmp (scheme, "file") == 0)
 	{
-		host_name = _("Local files");
+		host_name = g_strdup (_("Local files"));
 		host_locations = g_list_append (host_locations,
 						g_strdup ("file:///"));
 	}
@@ -699,23 +664,34 @@ internal_get_host (EphyHistory *eh, const char *url, gboolean create)
 	{
 		char *location;
 		char *tmp;
+		
+		if (g_str_equal (scheme, "https"))
+		{
+			/* If scheme is https, we still fake http. */
+			location = g_strconcat ("http://", host_name, "/", NULL);
+			host_locations = g_list_append (host_locations, location);
+		}
 
+		/* We append the real address */
 		location = g_strconcat (scheme,
 					"://", host_name, "/", NULL);
 		host_locations = g_list_append (host_locations, location);
 
-		if (g_str_has_prefix (host_name, "www."))
+		/* and also a fake www-modified address if it's http or https. */
+		if (g_str_has_prefix (scheme, "http"))
 		{
-			tmp = g_strdup (g_utf8_offset_to_pointer (host_name, 4));
+			if (g_str_has_prefix (host_name, "www."))
+			{
+				tmp = g_strdup (host_name + 4);
+			}
+			else
+			{
+				tmp = g_strconcat ("www.", host_name, NULL);
+			}
+			location = g_strconcat ("http://", tmp, "/", NULL);
+			g_free (tmp);
+			host_locations = g_list_append (host_locations, location);
 		}
-		else
-		{
-			tmp = g_strconcat ("www.", host_name, NULL);
-		}
-		location = g_strconcat (gnome_vfs_uri_get_scheme (vfs_uri),
-					"://", tmp, "/", NULL);
-		g_free (tmp);
-		host_locations = g_list_append (host_locations, location);
 	}
 
 	g_return_val_if_fail (host_locations != NULL, NULL);
@@ -755,10 +731,8 @@ internal_get_host (EphyHistory *eh, const char *url, gboolean create)
 		ephy_history_host_visited (eh, host, now);
 	}
 
-	if (vfs_uri)
-	{
-		gnome_vfs_uri_unref (vfs_uri);
-	}
+	g_free (scheme);
+	g_free (host_name);
 
 	g_list_foreach (host_locations, (GFunc)g_free, NULL);
 	g_list_free (host_locations);
