@@ -15,19 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
 
-#include "ephy-zoom-control.h"
-#include "ephy-marshal.h"
-#include "ephy-zoom.h"
-#include "ephy-debug.h"
-
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
+#include "ephy-zoom-control.h"
+#include "ephy-zoom.h"
+
 #define EPHY_ZOOM_CONTROL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ZOOM_CONTROL, EphyZoomControlPrivate))
 
 struct _EphyZoomControlPrivate
@@ -51,39 +47,11 @@ enum
 
 static guint signals[LAST_SIGNAL];
 
-static GObjectClass *parent_class = NULL;
-
 static void	ephy_zoom_control_class_init	(EphyZoomControlClass *klass);
 static void	ephy_zoom_control_init		(EphyZoomControl *control);
-static void	ephy_zoom_control_finalize	(GObject *o);
+static void	ephy_zoom_control_dispose	(GObject *o);
 
-GType
-ephy_zoom_control_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-			{
-				sizeof (EphyZoomControlClass),
-				NULL, /* base_init */
-				NULL, /* base_finalize */
-				(GClassInitFunc) ephy_zoom_control_class_init,
-				NULL,
-				NULL, /* class_data */
-				sizeof (EphyZoomControl),
-				0, /* n_preallocs */
-				(GInstanceInitFunc) ephy_zoom_control_init,
-			};
-
-		type = g_type_register_static (GTK_TYPE_TOOL_ITEM,
-					       "EphyZoomControl",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (EphyZoomControl, ephy_zoom_control, GTK_TYPE_TOOL_ITEM)
 
 static void
 combo_changed_cb (GtkComboBox *combo, EphyZoomControl *control)
@@ -200,14 +168,12 @@ ephy_zoom_control_class_init (EphyZoomControlClass *klass)
 	GObjectClass *object_class;
 	GtkToolItemClass *tool_item_class;
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class = (GObjectClass *)klass;
 	tool_item_class = (GtkToolItemClass *)klass;
 
 	object_class->set_property = ephy_zoom_control_set_property;
 	object_class->get_property = ephy_zoom_control_get_property;
-	object_class->finalize = ephy_zoom_control_finalize;
+	object_class->dispose = ephy_zoom_control_dispose;
 
 	g_object_class_install_property (object_class,
 					 PROP_ZOOM,
@@ -233,15 +199,27 @@ ephy_zoom_control_class_init (EphyZoomControlClass *klass)
 }
 
 static void
-ephy_zoom_control_finalize (GObject *o)
+ephy_zoom_control_dispose (GObject *o)
 {
 	EphyZoomControl *control = EPHY_ZOOM_CONTROL (o);
 
-	g_object_unref (control->priv->combo);
+	if (control->priv->combo)
+	{
+		g_object_unref (control->priv->combo);
+		control->priv->combo = NULL;
+	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (o);
+	G_OBJECT_CLASS (ephy_zoom_control_parent_class)->dispose (o);
 }
 
+/**
+ * ephy_zoom_control_set_zoom_level:
+ * @control: an #EphyZoomControl
+ * @zoom: the new value for the zoom level
+ *
+ * Sets the zoom level of @control.
+ *
+ **/
 void
 ephy_zoom_control_set_zoom_level (EphyZoomControl *control, float zoom)
 {
@@ -253,6 +231,15 @@ ephy_zoom_control_set_zoom_level (EphyZoomControl *control, float zoom)
 	g_object_notify (G_OBJECT (control), "zoom");
 }
 
+/**
+ * ephy_zoom_control_get_zoom_level:
+ * @control: an #EphyZoomControl
+ *
+ * Get the current zoom level of @control.
+ *
+ * Returns: the zoom level as a float
+ *
+ **/
 float
 ephy_zoom_control_get_zoom_level (EphyZoomControl *control)
 {
