@@ -15,7 +15,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id$
  */
 
 #include "config.h"
@@ -23,7 +22,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-stock-icons.h>
 #include <string.h>
 
 #include "ephy-bookmarks-editor.h"
@@ -1580,33 +1578,12 @@ search_entry_search_cb (GtkWidget *entry, const char *search_text, EphyBookmarks
 	ephy_node_filter_done_changing (editor->priv->bookmarks_filter);
 }
 
-static gboolean
-search_entry_clear_cb (GtkWidget *ebox,
-					   GdkEventButton *event,
-					   GtkWidget *entry)
-{
-	guint state = event->state & gtk_accelerator_get_default_mod_mask ();
-	
-	if (event->type == GDK_BUTTON_RELEASE && 
-	    event->button == 1 && 
-	    state == 0 /* left */)
-	{
-		ephy_search_entry_clear (EPHY_SEARCH_ENTRY (entry));
-		
-		return TRUE;
-	}
-	
-	return FALSE;
-}
-
 static GtkWidget *
 build_search_box (EphyBookmarksEditor *editor)
 {
 	GtkWidget *box;
 	GtkWidget *label;
 	GtkWidget *entry;
-	GtkWidget *cleaner;
-	GtkWidget *ebox;
 	char *str;
 
 	box = gtk_hbox_new (FALSE, 6);
@@ -1616,21 +1593,6 @@ build_search_box (EphyBookmarksEditor *editor)
 	entry = ephy_search_entry_new ();
 	editor->priv->search_entry = entry;
 	
-	cleaner = gtk_image_new_from_stock (GTK_STOCK_CLEAR,
-					    GTK_ICON_SIZE_MENU);
-	ebox = gtk_event_box_new ();
-	gtk_event_box_set_visible_window (GTK_EVENT_BOX (ebox), FALSE);
-	
-	gtk_widget_add_events (ebox, GDK_BUTTON_PRESS_MASK |
-			       GDK_BUTTON_RELEASE_MASK);
-	g_signal_connect (ebox , "button-release-event",
-			  G_CALLBACK (search_entry_clear_cb), 
-			  entry);
-	gtk_widget_set_tooltip_text (ebox,
-			             _("Clear"));
-	gtk_container_add (GTK_CONTAINER (ebox), cleaner);
-	ephy_icon_entry_pack_widget ((EPHY_ICON_ENTRY (entry)), ebox, FALSE);
-	
 	g_signal_connect (G_OBJECT (entry), "search",
 			  G_CALLBACK (search_entry_search_cb),
 			  editor);
