@@ -16,7 +16,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -117,7 +116,7 @@ activate_bookmark_properties (GtkAction *action,
 
 	widget = gtk_widget_get_ancestor (egg_editable_toolbar_get_selected (etoolbar),
 					  GTK_TYPE_TOOL_ITEM);
-	baction = widget ? gtk_widget_get_action (widget) : NULL;
+	baction = widget ? gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget)) : NULL;
 	g_return_if_fail (EPHY_IS_BOOKMARK_ACTION (baction));
 
 	ephy_bookmarks_ui_show_bookmark (ephy_bookmark_action_get_bookmark
@@ -133,7 +132,7 @@ activate_bookmark_open_tab (GtkAction *action,
 
 	widget = gtk_widget_get_ancestor (egg_editable_toolbar_get_selected (etoolbar),
 					  GTK_TYPE_TOOL_ITEM);
-	baction = widget ? gtk_widget_get_action (widget) : NULL;
+	baction = widget ? gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget)) : NULL;
 	g_return_if_fail (EPHY_IS_BOOKMARK_ACTION (baction));
 
 	ephy_bookmark_action_activate (EPHY_BOOKMARK_ACTION (baction), widget,
@@ -149,7 +148,7 @@ activate_bookmark_open_window (GtkAction *action,
 
 	widget = gtk_widget_get_ancestor (egg_editable_toolbar_get_selected (etoolbar),
 					  GTK_TYPE_TOOL_ITEM);
-	baction = widget ? gtk_widget_get_action (widget) : NULL;
+	baction = widget ? gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget)) : NULL;
 	g_return_if_fail (EPHY_IS_BOOKMARK_ACTION (baction));
 
 	ephy_bookmark_action_activate (EPHY_BOOKMARK_ACTION (baction), widget,
@@ -171,7 +170,7 @@ selected_bookmark_action (EggEditableToolbar *etoolbar,
 	{
 		widget = egg_editable_toolbar_get_selected (etoolbar);
 		widget = widget ? gtk_widget_get_ancestor (widget, GTK_TYPE_TOOL_ITEM) : NULL;
-		baction = widget ? gtk_widget_get_action (widget) : NULL;
+		baction = widget ? gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget)) : NULL;
 		visible = EPHY_IS_BOOKMARK_ACTION (baction);
 	}
 	  
