@@ -244,7 +244,7 @@ confirmation_dialog_construct (EphyHistoryWindow *editor)
 	gtk_window_group_add_window (ephy_gui_ensure_window_group (GTK_WINDOW (editor)),
 				     GTK_WINDOW (dialog));
 	
-	button = gtk_button_new_with_label (_("Cl_ear"));
+	button = gtk_button_new_with_mnemonic (_("Cl_ear"));
 	image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (button), image);
 	/* don't show the image! see bug #307818 */
