@@ -15,7 +15,6 @@
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
-*  $Id$
 */
 
 #include "config.h"
@@ -233,11 +232,11 @@ static void
 connect_proxy (GtkAction *action,
 	       GtkWidget *proxy)
 {      
-	gchar *action_name;
+	const gchar *action_name;
 	
 	GTK_ACTION_CLASS (ephy_home_action_parent_class)->connect_proxy (action, proxy);
 	
-	 g_object_get (action, "name", &action_name, NULL);
+	action_name = gtk_action_get_name (action);
 
 	if (GTK_IS_TOOL_ITEM (proxy) && (strcmp (action_name, "GoHome") != 0))
 	{
