@@ -2,6 +2,8 @@
 /*
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
  *  Copyright © 2003, 2004 Christian Persch
+ *  Copyright © 2008 Jan Alonzo
+ *  Copyright © 2009 Igalia S.L.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,38 +19,37 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-navigation-action.c 7840 2007-12-31 13:35:27Z jmalonzo $
  */
 
 #include "config.h"
-
 #include "ephy-navigation-action.h"
-#include "ephy-type-builtins.h"
-#include "ephy-window.h"
-#include "ephy-favicon-cache.h"
-#include "ephy-history.h"
+
+#include "ephy-debug.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-shell.h"
-#include "ephy-history-item.h"
-#include "ephy-link.h"
+#include "ephy-embed-utils.h"
+#include "ephy-favicon-cache.h"
 #include "ephy-gui.h"
-#include "ephy-debug.h"
+#include "ephy-history.h"
+#include "ephy-link.h"
+#include "ephy-shell.h"
+#include "ephy-type-builtins.h"
+#include "ephy-window.h"
 
-#include <gtk/gtklabel.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkmenushell.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenutoolbutton.h>
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtkstatusbar.h>
+#include <gtk/gtk.h>
+#include <webkit/webkit.h>
 
-#define HISTORY_ITEM_DATA_KEY	"HistoryItem"
-#define URL_DATA_KEY	        "GoURL"
+#define HISTORY_ITEM_DATA_KEY	  "HistoryItem"
+#define URL_DATA_KEY	          "GoURL"
 
 #define EPHY_NAVIGATION_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NAVIGATION_ACTION, EphyNavigationActionPrivate))
 
+typedef enum
+{
+	WEBKIT_HISTORY_BACKWARD,
+	WEBKIT_HISTORY_FORWARD
+} WebKitHistoryType;
+
 struct _EphyNavigationActionPrivate
 {
 	EphyWindow *window;
@@ -68,35 +69,7 @@ enum
 static void ephy_navigation_action_init       (EphyNavigationAction *action);
 static void ephy_navigation_action_class_init (EphyNavigationActionClass *class);
 
-static GObjectClass *parent_class = NULL;
-
-GType
-ephy_navigation_action_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo type_info =
-		{
-			sizeof (EphyNavigationActionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) ephy_navigation_action_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (EphyNavigationAction),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_navigation_action_init,
-		};
-
-		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
-					       "EphyNavigationAction",
-					       &type_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (EphyNavigationAction, ephy_navigation_action, EPHY_TYPE_LINK_ACTION)
 
 #define MAX_LABEL_LENGTH 48
 
@@ -144,7 +117,7 @@ static void
 activate_back_or_forward_menu_item_cb (GtkWidget *menuitem,
 				       EphyNavigationAction *action)
 {
-	EphyHistoryItem *item;
+	WebKitWebHistoryItem *item;
 	EphyEmbed *embed;
 
 	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (action->priv->window));
@@ -157,26 +130,24 @@ activate_back_or_forward_menu_item_cb (GtkWidget *menuitem,
 		g_return_if_fail (embed != NULL);
 	}
 
-	item = (EphyHistoryItem*)g_object_get_data (G_OBJECT (menuitem), HISTORY_ITEM_DATA_KEY);
+	item = (WebKitWebHistoryItem*)g_object_get_data (G_OBJECT (menuitem), HISTORY_ITEM_DATA_KEY);
 	g_return_if_fail (item != NULL);
 
-	ephy_embed_go_to_history_item (embed, item);
+	webkit_web_view_go_to_back_forward_item (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed), item);
 }
 
 static void
 select_menu_item_cb (GtkWidget *menuitem,
 	             EphyNavigationAction *action)
 {
-	char *url;
+	const char *url;
 	GtkWidget *statusbar;
-	EphyHistoryItem *item;
-	char *freeme = NULL;
+	WebKitWebHistoryItem *item;
 
-	item = (EphyHistoryItem*)g_object_get_data (G_OBJECT (menuitem), HISTORY_ITEM_DATA_KEY);
+	item = (WebKitWebHistoryItem*)g_object_get_data (G_OBJECT (menuitem), HISTORY_ITEM_DATA_KEY);
 	if (item)
 	{
-		url = ephy_history_item_get_url (item);
-		freeme = url;
+		url = webkit_web_history_item_get_uri (item);
 	}
 	else
 	{
@@ -187,8 +158,6 @@ select_menu_item_cb (GtkWidget *menuitem,
 	statusbar = ephy_window_get_statusbar (action->priv->window);
 
 	gtk_statusbar_push (GTK_STATUSBAR (statusbar), action->priv->statusbar_cid, url);
-
-	g_free (freeme);
 }
 
 static void
@@ -219,6 +188,24 @@ activate_up_menu_item_cb (GtkWidget *menuitem,
 			ephy_gui_is_middle_click () ? EPHY_LINK_NEW_TAB : 0);
 }
 
+static GList*
+webkit_construct_history_list (WebKitWebView *web_view, WebKitHistoryType hist_type) 
+{
+	WebKitWebBackForwardList *web_back_forward_list;
+	GList *webkit_items;
+
+	web_back_forward_list = webkit_web_view_get_back_forward_list (web_view);
+
+	if (hist_type == WEBKIT_HISTORY_FORWARD)
+		webkit_items = g_list_reverse (webkit_web_back_forward_list_get_forward_list_with_limit (web_back_forward_list,
+													 EPHY_WEBKIT_BACK_FORWARD_LIMIT));
+	else
+		webkit_items = webkit_web_back_forward_list_get_back_list_with_limit (web_back_forward_list,
+										      EPHY_WEBKIT_BACK_FORWARD_LIMIT);
+
+	return webkit_items;
+}
+
 static GtkWidget *
 build_back_or_forward_menu (EphyNavigationAction *action)
 {
@@ -226,14 +213,20 @@ build_back_or_forward_menu (EphyNavigationAction *action)
 	GtkMenuShell *menu;
 	EphyEmbed *embed;
 	GList *list, *l;
+	WebKitWebView *web_view;
 
 	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_val_if_fail (embed != NULL, NULL);
 
+	web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+	g_return_val_if_fail (web_view != NULL, NULL);
+
 	if (action->priv->direction == EPHY_NAVIGATION_DIRECTION_BACK)
-		list = ephy_embed_get_backward_history (embed);
+		list = webkit_construct_history_list (web_view,
+						      WEBKIT_HISTORY_BACKWARD);
 	else
-		list = ephy_embed_get_forward_history (embed);
+		list = webkit_construct_history_list (web_view,
+						      WEBKIT_HISTORY_FORWARD);
 
 	menu = GTK_MENU_SHELL (gtk_menu_new ());
 
@@ -242,19 +235,17 @@ build_back_or_forward_menu (EphyNavigationAction *action)
 	for (l = list; l != NULL; l = l->next)
 	{
 		GtkWidget *item;
-		EphyHistoryItem *hitem;
-		char *title, *url;
+		WebKitWebHistoryItem *hitem;
+		const char *title, *url;
 
-		hitem = (EphyHistoryItem*)l->data;
-		url = ephy_history_item_get_url (hitem);
-		title = ephy_history_item_get_title (hitem);
+		hitem = (WebKitWebHistoryItem*)l->data;
+		url = webkit_web_history_item_get_uri (hitem);
+		title = webkit_web_history_item_get_title (hitem);
 
 		item = new_history_menu_item (title ? title : url, url);
 
-		g_free (title);
-
-		g_object_set_data_full (G_OBJECT (item), HISTORY_ITEM_DATA_KEY, hitem,
-					(GDestroyNotify) g_object_unref);
+		g_object_set_data_full (G_OBJECT (item), HISTORY_ITEM_DATA_KEY,
+					g_object_ref (hitem), g_object_unref);
 
 		g_signal_connect (item, "activate",
 				  G_CALLBACK (activate_back_or_forward_menu_item_cb),
@@ -294,7 +285,7 @@ build_up_menu (EphyNavigationAction *action)
     	history = EPHY_HISTORY
 		(ephy_embed_shell_get_global_history (embed_shell));
 
-	list = ephy_embed_get_go_up_list (embed);
+	list = ephy_web_view_get_go_up_list (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
 
 	for (l = list; l != NULL; l = l->next)
 	{
@@ -327,6 +318,7 @@ build_up_menu (EphyNavigationAction *action)
 	}
 
 	/* the list data has been consumed */
+	g_slist_foreach (list, (GFunc) g_free, NULL);
 	g_slist_free (list);
 
 	return GTK_WIDGET (menu);
@@ -379,7 +371,7 @@ connect_proxy (GtkAction *gaction,
 				  G_CALLBACK (menu_activated_cb), gaction);
 	}
 
-	GTK_ACTION_CLASS (parent_class)->connect_proxy (gaction, proxy);
+	GTK_ACTION_CLASS (ephy_navigation_action_parent_class)->connect_proxy (gaction, proxy);
 }
 
 static void
@@ -388,24 +380,63 @@ ephy_navigation_action_activate (GtkAction *gtk_action)
 	EphyNavigationAction *action = EPHY_NAVIGATION_ACTION (gtk_action);
 	EphyWindow *window = action->priv->window;
 	EphyEmbed *embed;
+	WebKitWebView *web_view;
 
 	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
+	web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+
 	if (action->priv->direction == EPHY_NAVIGATION_DIRECTION_BACK)
 	{
-		ephy_embed_go_back (embed);
+		if (ephy_gui_is_middle_click ())
+		{
+			embed = ephy_shell_new_tab (ephy_shell_get_default (),
+						    EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (embed))),
+						    embed,
+						    NULL,
+						    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
+			web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+		}
+		webkit_web_view_go_back (web_view);
 	}
 	else if (action->priv->direction == EPHY_NAVIGATION_DIRECTION_FORWARD)
 	{
-		ephy_embed_go_forward (embed);
+		if (ephy_gui_is_middle_click ())
+		{
+			const char *forward_uri;
+			WebKitWebHistoryItem *forward_item;
+			WebKitWebBackForwardList *history;
+
+			/* Forward history is not copied when opening
+			   a new tab, so get the forward URI manually
+			   and load it */
+			history = webkit_web_view_get_back_forward_list (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed));
+			forward_item = webkit_web_back_forward_list_get_forward_item (history);
+			forward_uri = webkit_web_history_item_get_original_uri (forward_item);
+
+			embed = ephy_shell_new_tab (ephy_shell_get_default (),
+						    EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (embed))),
+						    embed,
+						    NULL,
+						    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
+
+			web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+			webkit_web_view_load_uri (web_view, forward_uri);
+		} else
+			webkit_web_view_go_forward (EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed));
 	}
 	else if (action->priv->direction == EPHY_NAVIGATION_DIRECTION_UP)
 	{
+		GSList *up_list;
+		
+		up_list = ephy_web_view_get_go_up_list (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed));
 		ephy_link_open (EPHY_LINK (action),
-				ephy_embed_get_go_up_list (embed)->data,
+				up_list->data,
 				NULL,
 				ephy_gui_is_middle_click () ? EPHY_LINK_NEW_TAB : 0);
+		g_slist_foreach (up_list, (GFunc) g_free, NULL);
+		g_slist_free (up_list);
 	}
 }
 
@@ -422,7 +453,7 @@ ephy_navigation_action_finalize (GObject *object)
 
 	g_free (action->priv->arrow_tooltip);
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (ephy_navigation_action_parent_class)->finalize (object);
 }
 
 static void
@@ -491,8 +522,6 @@ ephy_navigation_action_class_init (EphyNavigationActionClass *class)
 	object_class->set_property = ephy_navigation_action_set_property;
 	object_class->get_property = ephy_navigation_action_get_property;
 
-	parent_class = g_type_class_peek_parent (class);
-
 	action_class->toolbar_item_type = GTK_TYPE_MENU_TOOL_BUTTON;
 	action_class->connect_proxy = connect_proxy;
 	action_class->activate = ephy_navigation_action_activate;
